/*
*******************************************************************************
**
**  This device driver was created by Applilet for the 78K0S/KB1+, 78K0S/KA1+,
**  78K0S/KY1+,78K0S/KU1+ 8-Bit Single-Chip Microcontrollers
**
**  Copyright(C) NEC Electronics Corporation 2002-2006
**  All rights reserved by NEC Electronics Corporation.
**
**  This program should be used on your own responsibility.
**  NEC Electronics Corporation assumes no responsibility for any losses
**  incurred by customers or third parties arising from the use of this file.
**
**  Filename :	timer.c
**  Abstract :	This file implements device driver for the timer module.
**  APIlib :	NEC78K0SKX1+.lib V1.70 [7 Dec. 2006]
**
**  Device :	uPD78F9222
**
**  Compiler :	NEC/CC78K0
**
*******************************************************************************
*/

/*
*******************************************************************************
**  Include files
*******************************************************************************
*/
#include "macrodriver.h"
#include "timer.h"


/*
*******************************************************************************
**  MacroDefine
*******************************************************************************
*/

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function initializes TM00_module.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
void TM00_Init( void )
{
	TMC00 = 0x00;
	SetIORBit(MK0, 0x20);
	SetIORBit(MK0, 0x40);
	ClrIORBit(IF0, 0x20);	
	ClrIORBit(IF0, 0x40);		
	PRM00 |= TM_TM00_CLOCK;		/* internal count clock */
	ClrIORBit(CRC00, 0x01);		/* TM00 squarewave output */	
	CR000 = TM_TM00_SQUAREWIDTH;
	CR010 = 0xffff;	

		
	ClrIORBit(PM3, 0x2);		/* TO00(P31) output */
	TOC00 = 0x7;			/* init low */
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function can start the TM00 counter.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
void TM00_Start( void )
{
	TMC00 = 0x0c;			/* squarewave output start */
	TOE00 = 0x01;
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function can stop the TM00 counter and clear the count register.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
void TM00_Stop( void )
{
	TMC00 = 0x0;
	TOE00 = 0x0;
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function can change TM00 condition.
**	
**  Parameters:
**	*array_reg :	value(s) to set condition
**	array_num :	value number
**
**  Returns:
**	MD_OK
**	MD_ERROR
**
**-----------------------------------------------------------------------------
*/
MD_STATUS TM00_ChangeTimerCondition( USHORT *array_reg, USHORT array_num )
{
	switch ( array_num )
	{
		case 2:
			CR010 = *( array_reg + 1 );
		case 1:
			CR000 = *( array_reg + 0 );
			break;
		default:
			return MD_ERROR;
	}
	return MD_OK;
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function initializes TM80 module.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
void TM80_Init()
{
	ClrIORBit(TMC80, 0x80);
	SetIORBit(MK1, 0x08);			/* INTTM80 disable */
	ClrIORBit(IF1, 0x08);
	/* Internal countclock */
	
	TMC80 |= ( TM_TM80_CLOCK << 1 );
	
	CR80 = TM_TM80_INTERVALVALUE;		/* TM80 interval timer */
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function can start the TM80 counter.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
void TM80_Start( )
{
	ClrIORBit(MK1, 0x08);			/* INTTM80 enable */
	SetIORBit(TMC80, 0x80);
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function can stop the TM80 counter operation.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
void TM80_Stop( )
{
	SetIORBit(MK1, 0x08);			/* INTTM80 disable */
	ClrIORBit(IF1, 0x08);
	ClrIORBit(TMC80, 0x80);
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function can change TM80 value.
**
**  Parameters:
**	UCHAR value
**
**  Returns:
**	MD_OK
**
**-----------------------------------------------------------------------------
*/
MD_STATUS TM80_ChangeTimerCondition( UCHAR value )
{
	CR80 = value;
	return MD_OK;
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function initializes TMH1 module.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
void TMH1_Init()
{
	ClrIORBit(TMHMD1, 0x80);
	SetIORBit(MK0, 0x10);			/* INTTMH1 disable */
	ClrIORBit(IF0, 0x10);
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function can start the TMH1 counter.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
void TMH1_Start( )
{
	SetIORBit(TMHMD1, 0x80);
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function can stop the TMH1 counter operation.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
void TMH1_Stop( )
{
	ClrIORBit(TMHMD1, 0x80);
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function can change TMH1 condition.
**
**  Parameters:
**	*array_reg :	value(s) to set condition
**	array_num :	value number
**
**  Returns:
**	MD_OK
**	MD_ERROR
**
**-----------------------------------------------------------------------------
*/
MD_STATUS TMH1_ChangeTimerCondition( UCHAR *array_reg, UCHAR array_num )
{
	switch( array_num )
	{
		case 2 :
			CMP11 = *(array_reg + 1);
		case 1 :
			CMP01 = *(array_reg + 0);
			break;
		default :
			return MD_ERROR;
	}
	return MD_OK;
}
